#include <Wire.h>;

#define pwrpin 3
#define gndpin 2

int sensorPin = 0;    // seleciona o pin para o potenciometro
int sensorValue = 0;  // guarda o valor do sensor

void setup()
{
	Serial.begin(19200);
	nunchuck_setpowerpins();
	nunchuck_init();
}

void loop()
{
	nunchuck_get_data();
	nunchuck_print_data();
	delay(50);
}

//

// Funçoes do Nunckuck

//

static uint8_t nunchuck_buf[6]; // array para guardar a data do nunchuck

// Uses port C (analog in) pins as power & ground for Nunchuck

static void nunchuck_setpowerpins()
{

	DDRC |= _BV(pwrpin) | _BV(gndpin);
	PORTC &=~ _BV(gndpin);
	PORTC |= _BV(pwrpin);
}


// initialize the I2C system, join the I2C bus,
// and tell the nunchuck we're talking to it

void nunchuck_init()
{
	Wire.begin(); // join i2c bus as master
	Wire.beginTransmission(0x52); // transmit to device 0x52
	Wire.send(0x40); // sends memory address
	Wire.send(0x00); // sends sent a zero.
	Wire.endTransmission(); // stop transmitting
}


// Send a request for data to the nunchuck
// was "send_zero()"
void nunchuck_send_request()
{
	Wire.beginTransmission(0x52); // transmit to device 0x52
	Wire.send(0x00); // sends one byte
	Wire.endTransmission(); // stop transmitting
}


// Receive data back from the nunchuck,
// returns 1 on successful read. returns 0 on failure
int nunchuck_get_data()
{
	int cnt=0;
	Wire.requestFrom (0x52, 6); // request data from nunchuck
	while (Wire.available ()) {
		// receive byte as an integer
		nunchuck_buf[cnt] = nunchuk_decode_byte(Wire.receive());
		cnt++;
	}

	nunchuck_send_request(); // send request for next data payload
	// If we recieved the 6 bytes, then go print them
	if (cnt >= 5) {
		return 1; // success
	}
	return 0; //failure
}


// Print the input data we have recieved
// accel data is 10 bits long
// so we read 8 bits, then we have to add
// on the last 2 bits. That is why I
// multiply them by 2 * 2

void nunchuck_print_data()
{
	static int i=0;
	int joy_x_axis = nunchuck_buf[0];
	int joy_y_axis = nunchuck_buf[1];
	int accel_x_axis = nunchuck_buf[2]; // * 2 * 2;
	int accel_y_axis = nunchuck_buf[3]; // * 2 * 2;
	int accel_z_axis = nunchuck_buf[4]; // * 2 * 2;
	int z_button = 0;
	int c_button = 0;

	// byte nunchuck_buf[5] contains bits for z and c buttons
	// it also contains the least significant bits for the accelerometer data
	// so we have to check each bit of byte outbuf[5]

	if ((nunchuck_buf[5] >> 0) & 1)
		z_button = 1;

	if ((nunchuck_buf[5] >> 1) & 1)
		c_button = 1;

	if ((nunchuck_buf[5] >> 2) & 1)
		accel_x_axis += 2;

	if ((nunchuck_buf[5] >> 3) & 1)
		accel_x_axis += 1;

	if ((nunchuck_buf[5] >> 4) & 1)
		accel_y_axis += 2;

	if ((nunchuck_buf[5] >> 5) & 1)
		accel_y_axis += 1;

	if ((nunchuck_buf[5] >> 6) & 1)
		accel_z_axis += 2;

	if ((nunchuck_buf[5] >> 7) & 1)
		accel_z_axis += 1;

	//Imprime os valores do X e Y do Joystick
	Serial.print(0x00);
	Serial.print(joy_x_axis,DEC);
	Serial.print(0x01);
	Serial.print(joy_y_axis, DEC);

}


// Encode data to format that most wiimote drivers except
// only needed if you use one of the regular wiimote drivers
char nunchuk_decode_byte (char x)
{
	x = (x ^ 0x17) + 0x17;
	return x;
}

